telepathy-qt: BaseChannelGroupInterface: Now we also always expose Properties flag.

Alexandr Akulich kaffeine at kemper.freedesktop.org
Sat Apr 23 08:33:21 UTC 2016


Module: telepathy-qt
Branch: master
Commit: b6a13e11947790485e70675e3f10aa740119d316
URL:    http://cgit.freedesktop.org/telepathy/telepathy-qt/commit/?id=b6a13e11947790485e70675e3f10aa740119d316

Author: Alexandr Akulich <akulichalexander at gmail.com>
Date:   Sat Feb 20 14:02:45 2016 +0500

BaseChannelGroupInterface: Now we also always expose Properties flag.

Tp::ChannelGroupFlagProperties and Tp::ChannelGroupFlagMembersChangedDetailed
flags now always ON. There is no reason to behave differently and this way we
improve source-level compatibility with future Telepathy specs.

---

 TelepathyQt/base-channel.cpp | 11 ++++++-----
 1 file changed, 6 insertions(+), 5 deletions(-)

diff --git a/TelepathyQt/base-channel.cpp b/TelepathyQt/base-channel.cpp
index f24c9cf..a7ae504 100644
--- a/TelepathyQt/base-channel.cpp
+++ b/TelepathyQt/base-channel.cpp
@@ -2607,7 +2607,7 @@ BaseChannelGroupInterface::Adaptee::~Adaptee()
 
 uint BaseChannelGroupInterface::Adaptee::groupFlags() const
 {
-    return mInterface->groupFlags() | Tp::ChannelGroupFlagMembersChangedDetailed;
+    return mInterface->groupFlags();
 }
 
 Tp::HandleOwnerMap BaseChannelGroupInterface::Adaptee::handleOwners() const
@@ -2864,16 +2864,17 @@ QVariantMap BaseChannelGroupInterface::immutableProperties() const
  */
 Tp::ChannelGroupFlags BaseChannelGroupInterface::groupFlags() const
 {
-    return mPriv->groupFlags;
+    return mPriv->groupFlags | Tp::ChannelGroupFlagProperties | Tp::ChannelGroupFlagMembersChangedDetailed;
 }
 
 /**
  * Set the group flags for this channel.
  *
  * The user interface can use this to present information about which operations are currently valid.
  * It is not recommended to set Tp::ChannelGroupFlagMembersChangedDetailed flag: MembersChangedDetailed
  * signal is implemented in the interface and enabled unconditionally, because there is no reason to
  * disable it and this improve compatibility with future Telepathy specs.
  *
  * \param flags The flags on this channel.
  *
@@ -2864,16 +2864,17 @@ QVariantMap BaseChannelGroupInterface::immutableProperties() const
  *
  * The user interface can use this to present information about which operations are currently valid.
- * It is not recommended to set Tp::ChannelGroupFlagMembersChangedDetailed flag: MembersChangedDetailed
- * signal is implemented in the interface and enabled unconditionally, because there is no reason to
- * disable it and this improve compatibility with future Telepathy specs.
+ * Take a note, that Tp::ChannelGroupFlagProperties and Tp::ChannelGroupFlagMembersChangedDetailed flags setted up
+ * unconditionally. This way we always provide modern properties (ChannelGroupFlagProperties) and automatically
+ * emit signal MembersChangedDetailed. There is no reason to behave differently and this improve compatibility with
+ * future Telepathy specs.
  *
  * \param flags The flags on this channel.



More information about the telepathy-commits mailing list